\documentstyle[12pt]{article}
%\renewcommand{\baselinestretch}{2}
%\renewcommand{\baselinestretch}{.5}
%\setlength{\topmargin}{-2mm}
%\setlength{\textheight}{7.85in}
%\setlength{\oddsidemargin}{.9in}
%\setlength{\textwidth}{13.4cm}
\title{The definability of physical concepts}
\author{Adonai S. Sant'Anna\thanks{Permanent address: Department of Mathematics,
Federal University of Paran\'a, P. O. Box 019081, Curitiba, PR,
81531-990. E-mail: adonai@ufpr.br.}}

\date{Department of Philosophy\\University of South Carolina\\Columbia, SC, 29208}
\begin{document}
\maketitle
%\renewcommand{\thesection}{\Roman{section}}
\newtheorem{definicao}{Definition}
\newtheorem{teorema}{Theorem}
\newtheorem{lema}{Lemma}
\newtheorem{corolario}{Corolary}
\newtheorem{proposicao}{Proposition}
\newtheorem{axioma}{Axiom}
\newtheorem{observacao}{Observation}

%\newpage

%\begin{center}

%{\Large The definability of physical concepts}

%\end{center}

\begin{abstract}
Our main purpose here is to make some considerations about the
definability of physical concepts like mass, force, time, space,
spacetime, and so on. Our starting motivation is a collection of
supposed definitions of closed system in the literature of physics
and philosophy of physics. So, we discuss the problem of
definitions in theoretical physics from the point of view of
modern theories of definition. One of our main conclusions is that
there are different kinds of definitions in physics that demand
different approaches. Within this context, we strongly advocate
the use of the axiomatic method in order to discuss some issues
concerning definitions.
\end{abstract}

%\tableofcontents

\section{Introduction}

In a recent paper Sungho Choi (2003) discussed the theory of
conserved quantities in physics. He criticized Christopher
Hitchcock's (1995) definition of closed system, which is a
strategic concept in order to cope with questions regarding
conserved quantities. According to Hitchcock, a closed system is a
system that does not engage in any {\it causal\/} interaction. In
other words, a closed system is a system that does not interact
with anything outside itself. In Choi's opinion, this kind of
point is advocated by other authors of standard textbooks on
physics like, e.g., Jerry Marion (1970). But Choi thinks that this
definition, which appeals to the notion of causality, entails
circularity, since causal processes and interactions are analyzed
in terms of conserved quantities that are in turn defined as
physical quantities governed by conservation laws. So,
conservation laws cannot invoke causation.

Hence, he introduced a new definition for closed systems which is
supposed to avoid circularity. Other advantages of this new
definition are presented in his paper.

Choi's paper is obviously interesting and provocative. But we
would like to make some remarks and criticisms and discuss some
alternative ideas to his approach. First, the author raises very
important questions about the foundations of physics, but a formal
approach, by means of the axiomatic method, would be more
appropriate, since the formalism in the axiomatic method allows us
a more objective discussion about definitions and their real role
in mathematics and in theoretical physics. We do advocate the use
of formal systems in order to talk about the notion of
definability in theoretical physics. The presence of mathematics
in physics is not a mere coincidence; it is a demand. Analogously,
we cannot be mathematically careless with respect to the
discussions on the foundations of physics. So, we believe that a
formal approach can give another taste to this subject, which is
more suitable to formal systems, where definitions play an
important role from the logical point of view. If philosophy is
supposed to deal with questions regarding the foundations of
physics (among other subjects), then we should at least think
about the possibility of using mathematics as one (although not
the only one) common language among scientific philosophers. In
this sense we completely agree with Patrick Suppes (1990) about
the role of the scientific philosopher nowadays; according to him:

\begin{quote}
We are no longer Sunday's preachers for Monday's scientific
workers, but we can participate in the scientific enterprise in a
variety of constructive ways. Certain foundational problems will
be solved better by philosophers than by anyone else. Other
problems of great conceptual interest will really depend for their
solution upon scientists deeply immersed in the discipline itself,
but illumination of the conceptual significance of the solutions
can be a proper philosophical role.
\end{quote}

In order to make our first point clearer, we recall a similar
question regarding the definability of concepts like mass and
force in classical mechanics. As is well known, some late XIX
century European physicists like Heinrich Hertz and Gustav
Kirchhoff were deeply concerned with the definability of the
concept of force in mechanics (Jammer, 2000; Sant'Anna, 1996). On
the other hand Ernst Mach tried to give the guidelines for a
notion of inertial mass (Sant'Anna and Maia, 2001). From the point
of view of Max Jammer (2000),

\begin{quote}
[a]ny proof of the undefinability of mass in terms of other
primitive notions can, of course, be given {\em only\/} within the
framework of an axiomatization of mechanics.
\end{quote}

The emphasis in the quote is ours. We would like to rephrase
Jammer's idea as another more generalized statement. We consider
that {\em any proof of either the formal undefinability or the
formal definability of physical concepts like mass, force, time,
space, closed systems, subsystems, etc., can be given\/} only {\em
within the framework of an axiomatic system\/}. Our justification
for this is as follows: the axiomatic framework is much more
objective than an intuitive or na\"{\i}ve approach. In this sense
we consider the words ``intuitive'' and ``na\"{\i}ve'' as
synonymous. For example, if we define a closed system as a system
that does not engage in any causal interactions, like it was
proposed by Hitchcock (1995), then a lot of questions should
remain, mainly with respect to the meaning of each terminology
used. Nevertheless, the main point is: what is supposed to mean a
system that does not engage in any causal interactions? Does that
mean that the resultant external force over the system is null? If
that is the case, then {\em there is\/} a causal interaction,
although this causal interaction is null. In other words, we
insist on the point of clarifying ideas by mean of formal
languages. What is a causal interaction? What is ``to engage in a
causal interaction''? What is a physical system?

We recognize that axiomatic systems represent a great deal of
restriction on intuitive ideas, causing a loss of generalization
in a sense. We do not think, e.g., that any physicist would
recognize any axiomatic system for classical particle mechanics as
a faithful picture of all the intuitive ideas concerning Newtonian
particle mechanics. Besides, it is usually unclear what does it
mean the label ``Newtonian mechanics''. Is Newtonian mechanics the
subject that we find in some textbooks like Goldstein's (1980) or
is Newtonian mechanics the set of ideas once stated by Isaac
Newton in his famous {\em Principia\/}? That is one of the reasons
why there is so many different axiomatic systems for physical
theories. A physical theory is much more than a mathematical
structure or a bunch of axioms. A physical theory is always
committed with experimental data. Nevertheless, if someone intends
to talk about the definability of physical concepts like, e.g.,
closed systems, then a very careful description should be given to
the notion of {\em definition\/}. There are many kinds of
definition in the literature. But formal definitions refer only to
formal languages, which are closely related to the axiomatic
method. If a researcher intends to work with informal definitions,
then this researcher should be very careful to answer the
following question: what theory of definition is he/she using?
What is a definition after all?

Our second point is that Choi should discuss in his paper why
circularity is a problem in a definition. It is important to
recall that circularity, from the point of view of some formal
theories of definition, entails the non-eliminability of the {\em
definiendum\/}. In other words, what kind of definition is the
author talking about? Is he suggesting the use of Le\'snewski's
theory of definition (Suppes, 1957), where eliminability {\em
is\/} an issue? Is he working with Tarski's theory of definition
(Just and Weese, 1995; Tarski, 1983)? If circularity is an issue,
what are other important questions regarding definitions? Some
authors consider that all definitions should be noncreative in the
sense that a definition should not allow a formula $F$ as a
theorem if this formula is not a theorem before the definition was
stated. In what sense that Choi's definition of closed system is
really more appropriate than Hitchcock's one? Is Choi's definition
noncreative? Is his definition an eliminable formula in the sense
of standard theories of definition like Le\'sniewski's or
Tarski's? Choi makes an interesting discussion from an intuitive
point of view. But what happens in a formal framework?

Finally, another issue seems to be somehow more difficult to cope
with. Choi's definition of closed system makes an explicit use of
the the notion of time. According to him, a system is closed with
respect to a physical quantity $Q$ at a time $t$ if and only if
either

\[\frac{dQ_{in}}{dt} = \frac{dQ_{out}}{dt} = 0\]

\noindent at $t$ or,

\[\frac{dQ_{in}}{dt} \neq \frac{-dQ_{out}}{dt}\]

\noindent at $t$, where $Q_{in}$ is the amount of $Q$ inside the
system and $Q_{out}$ is the amount of $Q$ outside the system. In
the case of physical quantities represented as vectors or tensors,
all you have to do is to consider that a system is closed if all
the components of the vector or tensor satisfy one of the two
conditions given above.

Our question is: isn't there any kind of fundamental relationship
between time and causality? In other words, how to prove that
Choi's definition of closed system is not circular at all? If
terminology is not settled in a very formal way, any discussion
like this seems to be pointless, although it may excite some
people in an intuitive manner. All strategic terms need to be
formally settled. The use of mathematical terminology in the
middle of any philosophical discussion does not entail the use of
any formal language. This is just informal language improved with
some technical notation which is usual in mathematics. What is a
definition? What is circularity? If these questions are properly
explained, then we are able to discuss about any problem related
to the definability of closed systems within a pragmatic spirit.

Following this introduction, the next section gives a very brief
approach to the problem of definitions in some fields of
scientific knowledge. In the third section Padoa's method is
discussed. Padoa's method is a logical technique that allows to
decide if some kinds of concepts are definable or not. In the next
section we use a well known axiomatization of classical particle
mechanics in order to make our main points concerning definitions
in physics. Further discussions are made at the last sections.

\section{Definitions in Science}

Definitions in science have one major role; they allow us to
introduce new terminologies in formal and natural languages. Such
new terminologies are, in a precise sense, eliminable,
dispensable, superfluous. For example, if we define the notion of
human being as a political animal, then the statement ``The human
being is weird'' may be rephrased as ``The political animal is
weird''. In other words, the {\em definiendum\/} ``human being''
may always be replaced by the {\em definiens\/} ``political
animal''. This illustration may cause false impressions, since
some definitions are contextual and not explicit. In contextual
definitions, the substitution of the {\em definiendum\/} by the
{\em definiens\/} is not so straightforward, since it depends on
the context of the statement where the substitution takes place.

Some authors have tried to present a general classification of
definitions (Gorsky, 1981; Pap, 1964; Runes, 1971). Here we
introduce a very brief classification at our own risk, based on a
book that we are publishing next year. We consider that every
definition introduces new terminologies to a language and that the
defined terminologies are always dispensable. If a new defined
terminology is somehow related (in a non-trivial manner) to a
formal language, then the definition is formal. Otherwise, we say
that the definition is informal.

Informal definitions are very common in natural languages like
English, for example. But we are mainly concerned here with formal
definitions.

There are at least three kinds of formal definitions: ampliative,
abbreviative, and Tarskian. An ampliative definition is that one
that {\em adds\/} new symbols to a formal language. A well known
example of ampliative theory of definitions is Le\'sniewski's
theory (Suppes, 1957). According to Stanislaw Le\'sniewski, every
definition is supposed to be eliminable and non-creative. The
criterion of eliminability says that the {\em definiendum\/} can
always be replaced by the {\em definiens\/} in any formula of the
formal language. There is a close relationship between
eliminability and circularity. If a given formula is circular,
then it is not eliminable; so, it is not a definition at all. For
details see (Suppes, 1957). The criterion of non-creativity says
that a definition cannot allow the demonstration of new theorems
that were impossible to prove before the definition was stated.
This is a very difficult criterion, since it seems to be some kind
of utopia. One example of a new result in a formal consistent
framework would be a contradiction. But since there is no general
method to verify if a theory is consistent, then the verification
of the criterion of non-creativity seems to represent a task that
in many cases is impossible to perform. So, it is not an easy task
to verify if a formula is really a definition.

An abbreviative definition is that one that uses a
metalinguistical symbol in order to {\em abbreviate\/} a sequence
of symbols from a formal language (Runes, 1971). For example, if
we want to define the existential quantifier in first order
languages by means of the universal quantifier, we do not need to
add the symbol ``$\exists$'' to the language. We can consider the
statement ``$\exists x(F)$'' as a metalinguistic abbreviation of
the well-formed formula ``$\neg\forall x(\neg F)$''. We are
obviously using standard notation for first-order languages, where
the symbol $\neg$ corresponds to the logical connective of
negation.

Finally, a Tarskian definition is that one that allows us to
define sets in set-theoretical structures that are used as
interpretations of formal languages (Just and Weese, 1995). If,
e.g., $\Lambda$ denotes a first order language and $M$ is a
set-theoretical interpretation of $\Lambda$, then a set $X$ of $M$
is definable if and only if there exists a well-formed formula
$\varphi(y)$ in $\Lambda$ with a single free occurrence of a
variable $y$ such that $x\in X$ iff $x$ satisfies the formula
$\varphi(y)$. In this case, the definability of sets in a
set-theoretical structure depends on the language $\Lambda$. For
details see the references.

Among the ampliative definitions we can still find two other kinds
of definitions, namely, semantical and synthatical. A semantical
definition is that one that adds a new symbol to a formal language
by means of a metalinguistic symbol like the usual ``$=_{def}$''.
For example, we can define the biconditional $\Leftrightarrow$ in
first-order languages as

\begin{equation}
(A\Leftrightarrow B) =_{def} (A\Rightarrow B)\wedge (B\Rightarrow
A),
\end{equation}

\noindent where standard notation is used for logical connectives
$\wedge$ and $\Rightarrow$.

A synthatical definition is that one which plays the role of an
eliminable and noncreative axiom in an axiomatic framework. In
this very bizarre situation, all definitions are new axioms. So,
any new definition corresponds actually to the ``definition'' of a
new theory. Many examples of this are given in (Suppes, 1957).

Informal definitions may be classified in many different ways. We
do not intend to elaborate on this difficult topic right now. We
can just say that there are operational definitions (Hempel,
1966), ostensive definitions (Gorsky, 1981), and many others
(Gorsky, 1981). So, we have the next diagram to summarize our
ideas for the sake of our purposes:

\[
\mbox{Definitions}\left\{
    \begin{array}{l}
    \mbox{Formal}
        \left\{
            \begin{array}{l}
            \mbox{Abbreviative}\\
            \mbox{Ampliative}
                \left\{
                \begin{array}{l}
                \mbox{Semantical}\\
                \mbox{Synthatical}
            \end{array}
            \right.\\
            \mbox{Tarskian}
    \end{array}
    \right.\\
    \mbox{Informal}
        \left\{
            \begin{array}{l}
            \mbox{Operational}\\
            \mbox{Ostensive}\\
            \mbox{Explicit}\\
            \mbox{Contextual}\\
\mbox{Other kinds}
    \end{array}
    \right.\\
    \end{array}
\right.
\]

\section{Padoa's method}

Summarizing the previous discussion, in an axiomatic system $S$ a
primitive term or concept $c$ is definable by means of the
remaining primitive concepts if and only if there is an
appropriate formula, provable in the system, that fixes the
meaning of $c$ as a function of the other primitive terms of $S$.
When $c$ is not definable in $S$, it is said to be independent of
the the other primitive terms.

There is a method, roughly introduced by Alessandro Padoa (1900)
and further developed by other logicians, which can be employed to
show either the independence or the dependence of concepts with
respect to remaining concepts. In fact, Padoa's method gives a
necessary and sufficient condition for independence in many formal
situations.

In order to present Padoa's method, some preliminary remarks are
necessary. Loosely speaking, if we are working in set theory, as
our basic framework, an axiomatic system $S$ is characterized by a
species of structures (da Costa and Chuaqui, 1988). Actually there
is a close relationship between species of structures and Suppes
predicates (Suppes, 2002); for details see (da Costa and Chuaqui,
1988). On the other hand, if our underlying logic is higher-order
logic (type theory), $S$ determines a usual higher-order structure
(Carnap, 1958). In the first case, our language is the first order
language of set theory, and, in the second, it is the language of
some type theory. Tarski (1983) showed that Padoa's method is
valid in the second case, and Beth (1953) that it is applicable in
the first one. A simplified and sufficiently rigorous formulation
of the Padoa's method, adapted to our exposition, is described in
the next paragraph.

Let $S$ be an axiomatic system whose primitive concepts are $c_1$,
$c_2$, ..., $c_n$. One of these concepts, say $c_i$, is
independent (undefinable) from the remaining if and only if there
are two models of $S$ in which $c_1$, ..., $c_{i-1}$, $c_{i+1}$,
..., $c_n$ have the same interpretation, but the interpretations
of $c_i$ in such models are different.

Of course a model of $S$ is a set-theoretical structure in which
all axioms of $S$ are true, according to the interpretation of its
primitive terms (Mendelson, 1997).

Next we briefly discuss a well known example of a physical theory
stated by means of axioms in order to discuss some points that
deserve more details.


\section{MSS System of Classical Particle Mechanics}

This section is essentially based on the axiomatization of
classical particle mechanics due to P. Suppes (1957), which is a
variant of the formulation by J. C. C. McKinsey, A. C. Sugar and
P. Suppes (1953). We call this McKinsey-Sugar-Suppes system of
classical particle mechanics as MSS system. MSS system will be
useful in order to allow us a discussion about the definability of
physical concepts like mass and time and even closed systems.

The reader should not understand that MSS system does faithfully
translate all the ideas behind Newtonian mechanics; but it
translates, in an intuitive manner, some of the main aspects of
Newton's ideas concerning mechanics.

MSS system has six primitive notions: $P$, $T$, $m$, ${\bf s}$,
${\bf f}$, and ${\bf g}$. $P$ and $T$ are sets, $m$ is a
real-valued unary function defined on $P$, ${\bf s}$ and ${\bf g}$
are vector-valued functions defined on the Cartesian product
$P\times T$, and ${\bf f}$ is a vector-valued function defined on
the Cartesian product $P\times P\times T$. Intuitively, $P$
corresponds to the set of particles and $T$ is to be physically
interpreted as a set of real numbers measuring elapsed times (in
terms of some unit of time, and measured from some origin of
time). $m(p)$ is to be interpreted as the numerical value of the
mass of $p\in P$. ${\bf s}_{p}(t)$, where $t\in T$, is a
$3$-dimensional vector which is to be physically interpreted as
the position of particle $p$ at instant $t$. ${\bf f}(p,q,t)$,
where $p$, $q\in P$, corresponds to the internal force that
particle $q$ exerts over $p$, at instant $t$. And finally, the
function ${\bf g}(p,t)$ is to be understood as the external force
acting on particle $p$ at instant $t$.

Now, we can give the axioms for MSS system.

\begin{definicao}
${\cal P} = \langle P,T,{\bf s},m,{\bf f},{\bf g}\rangle$ is a MSS
system if and only if the following axioms are satisfied:

\begin{description}

\item [P1] $P$ is a non-empty, finite set.

\item [P2] $T$ is an interval of real numbers.

\item [P3] If $p\in P$ and $t\in T$, then ${\bf s}_{p}(t)$ is a
$3$-dimensional vector (${\bf s}_p(t)\in\Re^3$) such that
$\frac{d^{2}{\bf s}_{p}(t)}{dt^{2}}$ exists.

\item [P4] If $p\in P$, then $m(p)$ is a positive real number.

\item [P5] If $p,q\in P$ and $t\in T$, then ${\bf f}(p,q,t) =
-{\bf f}(q,p,t)$.

\item [P6] If $p,q\in P$ and $t\in T$, then $[{\bf s}_{p}(t), {\bf
f}(p,q,t)] = -[{\bf s}_{q}(t), {\bf f}(q,p,t)]$.

\item [P7] If $p,q\in P$ and $t\in T$, then $m(p)\frac{d^{2}{\bf
s}_{p}(t)}{dt^{2}} = \sum_{q\in P}{\bf f}(p,q,t) + {\bf g}(p,t).$

\end{description}

\end{definicao}

The brackets [,] in axiom {\bf P6} denote the external product.

Axiom {\bf P5} corresponds to a weak version of Newton's Third
Law: to every force there is always a counter-force. Axioms {\bf
P6} and {\bf P5}, correspond to the strong version of Newton's
Third Law. Axiom {\bf P6} establishes that the direction of force
and counter-force is the direction of the line defined by the
coordinates of particles $p$ and $q$.

Axiom {\bf P7} corresponds to Newton's Second Law.

\begin{definicao}
Let ${\cal P} = \langle P,T,{\bf s},m,{\bf f},{\bf g}\rangle$ be a
MSS system, let $P'$ be a non-empty subset of $P$, let ${\bf s}'$
and $m'$ be, respectively, the restrictions of functions ${\bf
s}$, and $m$ with their first arguments restricted to $P'$, and
let ${\bf f}'$ be the restriction of ${\bf f}$ with its first two
arguments restricted to $P'$. Then ${\cal P'} = \langle P',T,{\bf
s}',m',{\bf f}',{\bf g}'\rangle$ is a subsystem of ${\cal P}$ iff
${\bf g}':P'\times T\to \Re^3$ is defined as follows:
\begin{equation}
{\bf g}'(p,t) = \sum_{q\in P-P'}{\bf f}(p,q,t) + {\bf g}(p,t).
\end{equation}
\label{P7}
\end{definicao}

\begin{teorema}
Every subsystem of a MSS system is again a MSS system.
\end{teorema}

\begin{definicao}
Two MSS systems \[{\cal P} = \langle P,T,{\bf s},m,{\bf f},{\bf
g}\rangle\] and
\[{\cal P'} = \langle P',T',{\bf s}',m',{\bf f}',{\bf g}'\rangle\] are equivalent if
and only if $P=P'$, $T=T'$, ${\bf s}={\bf s}'$, and $m=m'$.
\end{definicao}

\begin{definicao}\label{closed}
A MSS system is isolated if and only if for every $p\in P$ and
$t\in T$, ${\bf g}(p,t) = \langle 0,0,0\rangle$.
\end{definicao}

This is a well known definition for isolated systems, which may be
termed closed systems as well. It does not say that a closed
system does not engage in any causal interaction. Actually, causal
interactions (which we interpret as the external forces ${\bf
g}(p,t)$ and internal forces ${\bf f}(p,q,t)$ for all $p, q\in P$
and all $t\in T$) are unavoidable. Besides, this definition can be
easily adapted to isolated particles. But the question is: is this
really a definition?

The embedding theorem is the following:

\begin{teorema}
Every MSS system is equivalent to a subsystem of an isolated MSS
system.\label{Her}
\end{teorema}

The next theorem can easily be proved by Padoa's method:

\begin{teorema}
Mass and internal force are each independent of the remaining
primitive notions of MSS system.
\end{teorema}

    According to Suppes (1957):

\begin{quote}
Some authors have proposed that we convert the second law [of
Newton], that is, {\rm \bf P7}, into a definition of the total
force acting on a particle. [...] It prohibits within the
axiomatic framework any analysis of the internal and external
forces acting on a particle. That is, if all notions of force are
eliminated as primitive and {\rm \bf P7} is used as a definition,
then the notions of internal and external force are not definable
within the given axiomatic framework.
\end{quote}

In (da Costa and Sant'Anna, 2001 and 2002) the authors prove that
time is definable (thus dispensable) in some very natural
axiomatic frameworks for classical particle mechanics and even
thermodynamics. Besides, they prove in the first paper that
spacetime is also eliminable in general relativity, classical
electromagnetism, Hamiltonian mechanics, classical gauge theories,
and Dirac's electron.

Here is one of the theorems proved in the cited papers:

\begin{teorema}
Time is eliminable in MSS system.
\end{teorema}

The proof is quite trivial. According to Padoa's principle, the
pimitive concept $T$ in MSS system is independent from the
remaining primitive concepts (mass, position, internal force, and
external force) iff there are two models of MSS system such that
$T$ has two interpretations and the remaining primitive symbols
have the same interpretation. But these two interpretations are
not possible, since position ${\bf s}$, internal force ${\bf f}$,
and external force ${\bf g}$ are functions whose domains depend on
$T$. If we change the interpretation of $T$, then we change the
interpretation of three other primitive concepts, namely, ${\bf
s}$, ${\bf f}$, and ${\bf g}$. So, time is not independent and
hence can be defined. Since time is definable, it is eliminable.

In (da Costa and Sant'Anna, 2002) the authors show that time is
dispensable in thermodynamics as well, at least in a specific
(although very natural) axiomatic framework for thermodynamics.
Besides, in the same paper they show how to define time and how to
rephrase thermodynamics without any explicit reference to time. In
the case of MSS system, time can be defined by means of the domain
of the functions ${\bf s}$, ${\bf f}$, and ${\bf g}$. A similar
procedure is used in (da Costa and Sant'Anna, 2002).

The definition of time in MSS system is an example of a Tarskian
definition, since we are defining a set in a set-theoretical
species of structures which is known here as MSS system.
Nevertheless, the definition of closed system given above is a
quite different kind of definition. If we do not make all clear,
we can never guess what kind of definition is that one.

The question is: what kind of definition is Definition
(\ref{closed})? It is important to remark that Definition
(\ref{closed}) does not refer to a set defined by means of
primitive concepts of MSS system. Definition (\ref{closed}) seems
more likely with an informal definition by postulates. If that is
the case, we cannot use Padoa's method in order to know if that is
really a definition. If Padoa's method is applicable, this is a
good criterion to see if a given concept is definable by means of
other concepts. But Definition (\ref{closed}) seems to be out of
our scope. So, further analysis are demanded in future works.

There are other philosophical issues concerning MSS system that
were settled in a formal point of view, like the anthropomorphical
aspect of the concept of force, from Heinrich Hertz's (1956) point
of view (Sant'Anna, 1996, Sant'Anna and Garcia, 2003), and Ernst
Mach's (1974) principle of inertia (Sant'Anna and Maia, 2001).

\section{Other Physical Theories}

According to Choi (2003), and we agree with that, ``it is
difficult to find a general formulation of a conservation law of
an arbitrary physical quantity in the literature of physics.'' We
agree with the idea that this lack of information makes general
statements concerning physical systems very difficult.
Nevertheless, we would like to point out that there is some
proposals of unifying pictures of physical theories in the
literature.

In (da Costa and Doria, 1992) there is a unified treatment for
physical theories that allows us to deal with Hamiltonian
mechanics, classical gauge field theories, Maxwell
electromagnetism, Dirac's electron, and Einstein's general
relativity. This unifying treatment is given by the next axiomatic
system:

\begin{definicao}
The species of structures of a {\em classical physical theory\/}
is given by the 9-tuple

$$\Sigma = \langle M, G, P, {\cal F}, {\cal A}, {\cal I}, {\cal
G}, B, \bigtriangledown\varphi = \iota\rangle$$

\noindent where

\begin{enumerate}

\item $M$ is a finite-dimensional smooth real manifold endowed
with a Riemannian metric (associated to spacetime) and $G$ is a
finite-dimensional Lie group (associated to transformations among
coordinate systems).

\item $P$ is a principal fiber bundle $P(M,G)$ over $M$ with Lie
group $G$.

\item ${\cal F}$, ${\cal A}$, and ${\cal I}$ are cross-sections of
bundles associated to $P(M,G)$, which correspond, respectively, to
the field space, potential space, and current or source space.

\item ${\cal G}\subseteq Diff(M)\otimes {\cal G}'$ is the symmetry
group of diffeomorphisms of $M$ and ${\cal G}'$ is the group of
gauge transformations of the principal fiber bundle $P(M,G)$.

\item $\bigtriangledown\varphi = \iota$ is a Dirac-like equation,
where $\varphi\in {\cal F}$ is a field associated to its potential
by means of a field equation and $\iota\in {\cal I}$ is a current.
Such a differential equation is subject to the boundary or initial
conditions $B$.

\end{enumerate}

\end{definicao}

Hence, we intend to develop some ideas concerning closed systems
for general physical systems based on some sort of axiomatic
framework like this. The present paper should be seen as an
introduction of a study on a general theory of definition in
physical theories.

\section{Conclusions}

Our main conclusions are:

\begin{enumerate}

\item There are many kinds of definitions in science and in
physics. If we want to talk about the definability of concepts, we
should make clear what kind of definition are we talking about.

\item If we do not want to discuss issues concerning definability
within an axiomatic framework, that's OK. But any discussion of
this nature will have the risk of being reduced to just opinions,
nothing else.

\item If we want to seriously discuss issues concerning the
definability of physical concepts, then we should consider the
explicit use of formal procedures usually adopted in logic.

\end{enumerate}

\section{Acknowledgements}

I would like to thank Ot\'avio Bueno and Davis Baird for their
hospitality during my stay at the Department of Philosophy of the
University of South Carolina.

This work was partially supported by CAPES (Brazilian government
agency).

%\newpage

\begin{thebibliography}{99}

\bibitem{Beth-53} Beth, E. W., `On Padoa's method in the theory of
definition' {\em Indag. Math.\/} {\bf 15} 330-339 (1953).

\bibitem{Carnap-58} Carnap, R., {\em Introduction to Symbolic
Logic and its Applications\/} (Dover, New York, 1958).

\bibitem{Choi-03} Choi, S., `The conserved quantity theory of
causation and closed systems', {\em Philosophy of Science\/} {\bf
70} 510-530 (2003).

\bibitem{daCosta-88} da Costa, N. C. A. and R. Chuaqui, `On
Suppes' set-theoretical predicates' {\em Erkenntnis\/} {\bf 29}
95-112 (1988).

\bibitem{daCosta-92} da Costa, N. C. A. and F. A. Doria, `Suppes
predicates for classical physics' in J. Echeverria et al. (eds.)
{\em The Space of Mathematics\/} (Berlin, Walter de Gruyer, 1992).

\bibitem{daCosta-01} da Costa, N. C. A. and A. S. Sant'Anna,
`The mathematical role of time and spacetime in classical
physics', {\em Foundations of Physics Letters\/} {\bf 14} 553-563
(2001).

\bibitem{daCosta-02} da Costa, N. C. A. and A. S. Sant'Anna,
`Time in thermodynamics', {\em Foundations of Physics\/} {\bf 32}
1785-1796 (2002).

\bibitem{Goldstein-80} Goldstein, H., {\em Classical Mechanics\/} (Reading, MA,
Addison-Wesley, 1980).

\bibitem{Gorsky-81} Gorsky, D. P., {\em Definition\/} (Moscow, Progress Publishers,
1981).

\bibitem{Hempel-66} Hempel, C., {\em Philosophy of Natural Science\/}
(Englewood Cliffs, N.J., Prentice-Hall, 1966).

\bibitem{Hertz-94} Hertz, H. R., {\em The Principles of Mechanics},
English translation by D. E. Jones and J. T. Walley (Dover, New
York, 1956).

\bibitem{Hitchcock-95} Hitchcock, C. R., `Discussion: Salmon on
explanatory relevance', {\em Philosophy of Science\/} {\bf 62}
304-320 (1995).

\bibitem{Jammer-00} Jammer, M., {\em Concepts of mass in contemporary physics and
philosophy\/} (Princeton, Princeton University Press, 2000).

\bibitem{Just-95} Just, W. and Weese, M., {\em Discovering Modern Set Theory. I.\/}
(Providence, AMS, 1995).

\bibitem{Mach-74} Mach, E., {\em The Science of Mechanics},
English translation by T. J. McCormack (Open Court, New York,
1974).

\bibitem{Marion-70} Marion, J. B., {\em Classical Dynamics of
Particles and Systems\/} (Academic Press, New York, 1970).

\bibitem{McKinsey-53} McKinsey, J. C. C., A. C. Sugar, and P. Suppes (1953),
`Axiomatic foundations of classical particle mechanics', {\em
Journal of Rational Mechanics and Analysis\/}, {\bf 2} 253-272.

\bibitem{Mendelson-97} Mendelson, E., {\em Introduction to
Mathematical Logic\/} (Chapman \& Hall, London, 1997).

\bibitem{Padoa-00} Padoa, A., `Essai d'une th\'eorie
alg\'ebrique des numbres entiers, pr\'ec\'ed\'e d'une introduction
logique \` a une th\'eorie d\'eductive quelconque' {\em
Bibliot\`eque du Congr\`es International de Philosophie\/} {\bf 3}
309--365 (1900).

\bibitem{Pap-64} Pap, A., `Theory of definition', {\em Philosophy of Science\/} {\bf
31} 49-54 (1964).

\bibitem{Runes-71} Runes, D. D., {\em Dictionary of Philosophy\/} (Littlefield,
Adams \& Co., 1971).

\bibitem{Sant'Anna-96} Sant'Anna, A. S., `An axiomatic framework
for classical particle mechanics without force', {\em Philosophia
Naturalis\/} {\bf 33} 187-203 (1996).

\bibitem{Sant'Anna-01} Sant'Anna, A. S. and C. A. S. Maia,
`Axioms for Mach's mechanics', {\em Foundations of Physics
Letters\/} {\bf 14} 247-262 (2001).

\bibitem{Sant'Anna-03} Sant'Anna, A. S. and C. Garcia, `Gravitation
in Hertz's mechanics', {\em Foundations of Physics Letters\/},
{\bf 16} 559-572 (2003).

\bibitem{Suppes-53} McKinsey, J. C. C., A. C. Sugar and P. Suppes,
`Axiomatic foundations of classical particle mechanics', {\em
Journal of Rational Mechanics and Analysis\/}, {\bf 2} 253-272
(1953).

\bibitem{Suppes-57} Suppes, P., {\em Introduction to Logic\/}
(Van Nostrand, Princeton, 1957).

\bibitem{Suppes-90} Suppes, P., `Philosophy and the sciences', in
W. Sieg  {\em Acting and Reflecting} 3-30 (Kluwer Academic,
Dordrecht, 1990).

\bibitem{Suppes-02} Suppes, P., {\em Representation and Invariance
of Scientific Structures\/} (CSLI, Stanford, 2002).

\bibitem{Tarski-83a} Tarski, A. ``On definable sets of real
numbers''. In: A. Tarski, {\em Logic, semantics,
metamathematics\/}, 110-142 (Indianapolis, Hacket Pub. Co., 1983).

\bibitem{Tarski-83b} Tarski, A., `Some methodological investigations
on the definability of concepts'. In: A. Tarski, {\em Logic,
semantics, metamathematics\/} 296--319 (Indianapolis, Hacket Pub.
Co., 1983).

\end{thebibliography}

\end{document}
